//
// Configure script for the reuse repo
//

import configure_functions;

import std.process;
import std.string;
import std.file;


void main(string args[]) {
    auto data = initialise(args, "doodle");

    //
    // open
    //

    // libssh2 and dependencies required by net
    usePackage(data, "libssh2", Constraint.AtLeast, "1.2");
    useHeader( data, "gcrypt.h");
    useLibrary(data, "libgcrypt.so");
    
    // TAO is required by corba-tao
    //useTao(data);


    //
    // reuse
    //

    usePackage(data, "libxml-2.0");
    usePackage(data, "libpng");
    usePackage(data, "freetype2");
    usePackage(data, "gtkmm-2.4", Constraint.AtLeast, "2.18");
    usePackage(data, "gtkglext-1.0");
    usePackage(data, "gstreamer-0.10", Constraint.AtLeast, "0.10.22");
    usePackage(data, "gstreamermm-0.10", Constraint.AtLeast, "0.10.1");
    usePackage(data, "xv");
    usePackage(data, "xext");
    usePackage(data, "xextproto");
    usePackage(data, "neon", Constraint.AtLeast, "0.28.2");
    usePackage(data, "libconfig", Constraint.AtLeast, "1.3.1");
    usePackage(data, "libconfig++", Constraint.AtLeast, "1.3.1");

    useHeader( data, "jpeglib.h");
    useLibrary(data, "libjpeg.so");

    useExecutable(data, "IMAGE_MAGICK_CONVERT", ["convert"]);
    useExecutable(data, "ZIP", ["zip"]);

    appendBobVar(data, "CCFLAGS",
                 ["-DGTKMM_MACRO_SHADOW_ERROR",
                 "-DGTKMM_DISABLE_DEPRECATED",
                 "-DGDKMM_DISABLE_DEPRECATED",
                 "-DGLIBMM_DISABLE_DEPRECATED",
                 "-DGDK_DISABLE_DEPRECATED",
                 "-DG_DISABLE_DEPRECATED",
                 "-DLIBSIGC_DISABLE_DEPRECATED",
                 "-DGTK_DISABLE_DEPRECATED",
                 "-DGSEAL_ENABLE"]);

    if (exists("/opt/acacia/ecw")) {
        string[][Use] dirs;
        dirs[Use.Inc] = ["/opt/acacia/ecw/include"];
        dirs[Use.Lib] = ["/opt/acacia/ecw/lib"];
        setProjectDirs(data, dirs);

        useHeader( data, "NCSFile.h");
        useLibrary(data, "libNCSUtil.so");
        useLibrary(data, "libNCSCnet.so");
        useLibrary(data, "libNCSEcw.so");

        appendBobVar(data, "CCFLAGS",       ["-DUSE_ECW_CHARTING_RASTER_SOURCE"]);
        appendBobVar(data, "ECW_LIBRARIES", ["NCSEcw", "NCSUtil", "NCSCnet"]);
    }


   appendRunVar(data, "GST_PLUGIN_PATH", ["${DIST_PATH}/lib/plugins"]);
   
   
   finalise(data, [/*"open"*/]);
}
